@@ -1,32 +1,18 @@
 /*
+    SPDX-FileCopyrightText: 2001 The Kompany
+    SPDX-FileCopyrightText: 2002-2003 Ilya Konstantinov <kde-devel@future.shiny.co.il>
+    SPDX-FileCopyrightText: 2002-2003 Marcus Meissner <marcus@jet.franken.de>
+    SPDX-FileCopyrightText: 2003 Nadeem Hasan <nhasan@nadmm.com>
 
-    Copyright (C) 2001 The Kompany
-          2002-2003	Ilya Konstantinov <kde-devel@future.shiny.co.il>
-          2002-2003	Marcus Meissner <marcus@jet.franken.de>
-          2003		Nadeem Hasan <nhasan@nadmm.com>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
+
 #ifndef __kamera_h__
 #define __kamera_h__
 
 #include <KCModule>
 #include <gphoto2.h>
 #include <KPluginFactory>
-#include <QLoggingCategory>
 
 class QWidget;
 class QPushButton;
@@ -41,8 +27,6 @@ class KConfig;
 class KActionCollection;
 class KToolBar;
 
-Q_DECLARE_LOGGING_CATEGORY(KAMERA_KCONTROL)
-
 class KKameraConfig : public KCModule
 {
     Q_OBJECT
@@ -77,7 +61,6 @@ protected Q_SLOTS:
 private:
     void displayGPFailureDialogue();
     void displayGPSuccessDialogue();
-    void displayCameraAbilities(const CameraAbilities &abilities);
     void populateDeviceListView();
     void beforeCameraOperation();
     void afterCameraOperation();
